%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

%global srcname uuidm

Name:           ocaml-%{srcname}
Version:        0.9.7
Release:        %mkrel 3
Summary:        Universally unique identifiers (UUIDs) for OCaml
Group:          Development/OCaml

License:        ISC
URL:            https://erratique.ch/software/uuidm
Source0:        https://github.com/dbuenzli/uuidm/archive/v%{version}/%{srcname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.03.0
BuildRequires:  ocaml-cmdliner-devel
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-ocamlbuild
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-ocamldoc
BuildRequires:  ocaml-topkg-devel

%description
Uuidm is an OCaml module implementing 128 bit universally unique
identifiers, versions 3, 5 (named based with MD5, SHA-1 hashing) and 4
(random based); see RFC 4122: http://tools.ietf.org/html/rfc4122.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n %{srcname}-%{version}

# The META file mistakenly uses the wrong version tag
sed -i 's/VERSION/VERSION_NUM/' pkg/META

# Topkg does watermark replacements only if run inside a git checkout.  Github
# tarballs do not come with a .git directory.  Therefore, we do the watermark
# replacement manually.
for fil in $(find . -type f); do
  sed -e 's,%%%%NAME%%%%,%{srcname},' \
      -e 's,%%%%PKG_HOMEPAGE%%%%,%{url},' \
      -e 's,%%%%VERSION%%%%,v%{version},' \
      -e 's,%%%%VERSION_NUM%%%%,%{version},' \
      -i.orig $fil
  touch -r $fil.orig $fil
  rm $fil.orig
done

%build
# Build the library and the tests
ocaml pkg/pkg.ml build --tests true --with-cmdliner true

# Build the documentation
mkdir html
ocamldoc -html -d html -I _build/src _build/src/uuidm.mli

%install
# Install the library
mkdir -p %{buildroot}%{_libdir}/ocaml/uuidm
cp -p _build/{opam,pkg/META} %{buildroot}%{_libdir}/ocaml/uuidm
%ifarch %{ocaml_native_compiler}
cp -a _build/src/*.{a,cma,cmi,cmt,cmti,cmx,cmxa,cmxs,mli} \
  %{buildroot}%{_libdir}/ocaml/uuidm
%else
cp -a _build/src/*.{cma,cmi,cmt,cmti,mli} %{buildroot}%{_libdir}/ocaml/uuidm
%endif

%check
ocaml pkg/pkg.ml test

%files
%doc CHANGES.md README.md
%license LICENSE.md
%dir %{_libdir}/ocaml/%{srcname}/
%{_libdir}/ocaml/%{srcname}/META
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cma
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmxs
%endif

%files devel
%doc html/*
%{_libdir}/ocaml/%{srcname}/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}/%{srcname}*.a
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmx
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmxa
%endif
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmt
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmti
%{_libdir}/ocaml/%{srcname}/%{srcname}*.mli



%changelog
* Thu May 19 2022 pterjan <pterjan> 0.9.7-3.mga9
+ Revision: 1859175
- Rebuild for OCaml 4.14

* Wed Oct 13 2021 tv <tv> 0.9.7-2.mga9
+ Revision: 1751238
- Rebuild for ocaml 4.13.1

* Wed Oct 13 2021 tv <tv> 0.9.7-1.mga9
+ Revision: 1751060
- Rebuild for ocaml 4.13.1

* Fri Mar 05 2021 tv <tv> 0.9.7-0.5.mga9
+ Revision: 1699886
- rebuild for ocaml-4.2-12

* Sun Jan 10 2021 pterjan <pterjan> 0.9.7-0.4.mga8
+ Revision: 1670734
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 0.9.7-0.3.mga8
+ Revision: 1551750
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 0.9.7-0.2.mga8
+ Revision: 1545756
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 0.9.7-0.1.mga8
+ Revision: 1485211
- new release + rebuild for ocaml-4.10
- rebuild for new ocaml

* Fri Feb 12 2016 umeabot <umeabot> 0.9.5-9.mga6
+ Revision: 956488
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.9.5-8.mga5
+ Revision: 740619
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.5-7.mga5
+ Revision: 683124
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.9.5-6.mga4
+ Revision: 535766
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 malo <malo> 0.9.5-5.mga4
+ Revision: 482509
- rebuild for ocaml-4.01.0

* Sun Jan 13 2013 umeabot <umeabot> 0.9.5-4.mga3
+ Revision: 361677
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 0.9.5-3.mga3
+ Revision: 301686
- new rpm group for ocaml

* Fri Sep 28 2012 blue_prawn <blue_prawn> 0.9.5-2.mga3
+ Revision: 299110
- new rpm group for ocaml

* Mon Aug 06 2012 blue_prawn <blue_prawn> 0.9.5-1.mga3
+ Revision: 279525
- updated to last version 0.9.5

* Sun Mar 25 2012 blue_prawn <blue_prawn> 0.9.4-1.mga3
+ Revision: 226157
- updated to new version 0.9.4 which now uses Oasis :,(

* Mon Jan 09 2012 blue_prawn <blue_prawn> 0.9.3-1.mga2
+ Revision: 194061
- imported package ocaml-uuidm

